var searchData=
[
  ['dbacolname_1075',['dbacolname',['../a00548.html#ga466690ceda8682382223d98a6ffb63bd',1,'dbacolname(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#ga466690ceda8682382223d98a6ffb63bd',1,'dbacolname(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbadata_1076',['dbadata',['../a00548.html#gabcc14a1ca58b65bc46cce6c81c45218c',1,'dbadata(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#gabcc14a1ca58b65bc46cce6c81c45218c',1,'dbadata(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbadlen_1077',['dbadlen',['../a00548.html#ga3340e21db274b272ec11c037cb147222',1,'dbadlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#ga3340e21db274b272ec11c037cb147222',1,'dbadlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltbind_1078',['dbaltbind',['../a00548.html#gafefd17e15b22adda84366c817178dd7d',1,'dbaltbind(DBPROCESS *dbproc, int computeid, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c'],['../a00548.html#gafefd17e15b22adda84366c817178dd7d',1,'dbaltbind(DBPROCESS *dbprocess, int computeid, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c']]],
  ['dbaltcolid_1079',['dbaltcolid',['../a00548.html#gad10c9fd75a86c7a0ac375937df0e90a6',1,'dbaltcolid(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#gad10c9fd75a86c7a0ac375937df0e90a6',1,'dbaltcolid(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltlen_1080',['dbaltlen',['../a00548.html#ga9a35c8d3cd0e35c10555baf8f6a01e93',1,'dbaltlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#ga9a35c8d3cd0e35c10555baf8f6a01e93',1,'dbaltlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltop_1081',['dbaltop',['../a00548.html#ga947837a5c8fd99898c043435945b668c',1,'dbaltop(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#ga947837a5c8fd99898c043435945b668c',1,'dbaltop(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbalttype_1082',['dbalttype',['../a00548.html#gaa85171e020dc606f2bd3395ad1d3ab4f',1,'dbalttype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#gaa85171e020dc606f2bd3395ad1d3ab4f',1,'dbalttype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltutype_1083',['dbaltutype',['../a00548.html#gaf1c00d83dfa88dc99a3fb449c49660ea',1,'dbaltutype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00548.html#gaf1c00d83dfa88dc99a3fb449c49660ea',1,'dbaltutype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbanullbind_1084',['dbanullbind',['../a00548.html#ga939c2a2e67b9992c787e2cec5b6cc1a7',1,'dbanullbind(DBPROCESS *dbproc, int computeid, int column, DBINT *indicator):&#160;dblib.c'],['../a00548.html#ga939c2a2e67b9992c787e2cec5b6cc1a7',1,'dbanullbind(DBPROCESS *dbprocess, int computeid, int column, DBINT *indicator):&#160;dblib.c']]],
  ['dbanydatecrack_1085',['dbanydatecrack',['../a00548.html#gad57aa777300cf7f62077478ec6000d00',1,'dbanydatecrack(DBPROCESS *dbproc, DBDATEREC2 *di, int type, const void *data):&#160;dblib.c'],['../a00548.html#gad57aa777300cf7f62077478ec6000d00',1,'dbanydatecrack(DBPROCESS *dbproc, DBDATEREC2 *di, int type, const void *data):&#160;dblib.c']]],
  ['dbbind_1086',['dbbind',['../a00548.html#ga873bc0f4663165e711655ade1dfae795',1,'dbbind(DBPROCESS *dbproc, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c'],['../a00548.html#ga873bc0f4663165e711655ade1dfae795',1,'dbbind(DBPROCESS *dbproc, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c']]],
  ['dbbylist_1087',['dbbylist',['../a00548.html#gae658a0cd5270f3bd6f22de17b2cb2e64',1,'dbbylist(DBPROCESS *dbproc, int computeid, int *size):&#160;dblib.c'],['../a00548.html#gae658a0cd5270f3bd6f22de17b2cb2e64',1,'dbbylist(DBPROCESS *dbproc, int computeid, int *size):&#160;dblib.c']]],
  ['dbcancel_1088',['dbcancel',['../a00548.html#ga5ea23272124fff03b8d87538c1ec3ee5',1,'dbcancel(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga5ea23272124fff03b8d87538c1ec3ee5',1,'dbcancel(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcanquery_1089',['dbcanquery',['../a00548.html#ga559e24ba70d0d96c3469eb6ab8f74e05',1,'dbcanquery(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga559e24ba70d0d96c3469eb6ab8f74e05',1,'dbcanquery(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbchange_1090',['dbchange',['../a00548.html#ga8cbc761b1266bd947783d843aeeec264',1,'dbchange(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga8cbc761b1266bd947783d843aeeec264',1,'dbchange(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbclose_1091',['dbclose',['../a00548.html#gaef740b394b44eb33925c2718f7b30d69',1,'dbclose(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gaef740b394b44eb33925c2718f7b30d69',1,'dbclose(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbclrbuf_1092',['dbclrbuf',['../a00548.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c'],['../a00548.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c']]],
  ['dbclropt_1093',['dbclropt',['../a00548.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00548.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
  ['dbcmd_1094',['dbcmd',['../a00548.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c'],['../a00548.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c']]],
  ['dbcmdrow_1095',['dbcmdrow',['../a00554.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcolinfo_1096',['dbcolinfo',['../a00080.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c'],['../a00506.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c']]],
  ['dbcollen_1097',['dbcollen',['../a00548.html#ga89fc5589b4bf41932324d2cfc6ad6433',1,'dbcollen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga89fc5589b4bf41932324d2cfc6ad6433',1,'dbcollen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolname_1098',['dbcolname',['../a00548.html#gad06f5deddac18604dfa858b2580e232f',1,'dbcolname(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gad06f5deddac18604dfa858b2580e232f',1,'dbcolname(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolptr_1099',['dbcolptr',['../a00554.html#ga0fc84c7073ed4876d9596c3eccac3609',1,'dblib.c']]],
  ['dbcolsource_1100',['dbcolsource',['../a00548.html#ga3a96d0188e5e0eb9eea661b3685fdcc3',1,'dbcolsource(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga3a96d0188e5e0eb9eea661b3685fdcc3',1,'dbcolsource(DBPROCESS *dbproc, int colnum):&#160;dblib.c']]],
  ['dbcoltype_1101',['dbcoltype',['../a00548.html#ga636e6f1b64743f3cf22158a56eef371f',1,'dbcoltype(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga636e6f1b64743f3cf22158a56eef371f',1,'dbcoltype(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcoltypeinfo_1102',['dbcoltypeinfo',['../a00548.html#ga3c33e72c41b40e08dbcfdfa0d16bc399',1,'dbcoltypeinfo(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga3c33e72c41b40e08dbcfdfa0d16bc399',1,'dbcoltypeinfo(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolutype_1103',['dbcolutype',['../a00548.html#gab33d2f4fd44f50e55b6c71902db4fdae',1,'dbcolutype(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gab33d2f4fd44f50e55b6c71902db4fdae',1,'dbcolutype(DBPROCESS *dbprocess, int column):&#160;dblib.c']]],
  ['dbconvert_1104',['dbconvert',['../a00548.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c'],['../a00548.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c']]],
  ['dbconvert_5fps_1105',['dbconvert_ps',['../a00548.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbproc, int db_srctype, const BYTE *src, DBINT srclen, int db_desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c'],['../a00548.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbprocess, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c']]],
  ['dbcount_1106',['dbcount',['../a00548.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcurcmd_1107',['dbcurcmd',['../a00554.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcurrow_1108',['dbcurrow',['../a00554.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbdata_1109',['dbdata',['../a00548.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbdatecmp_1110',['dbdatecmp',['../a00553.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c'],['../a00553.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c']]],
  ['dbdatecrack_1111',['dbdatecrack',['../a00548.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *datetime):&#160;dblib.c'],['../a00548.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *dt):&#160;dblib.c']]],
  ['dbdatlen_1112',['dbdatlen',['../a00548.html#gae666d141533126babb0235af21bdca0f',1,'dbdatlen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gae666d141533126babb0235af21bdca0f',1,'dbdatlen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbdead_1113',['dbdead',['../a00554.html#gaed43cb21ed54dc1a6340075d6290e4b0',1,'dbdead(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#gaed43cb21ed54dc1a6340075d6290e4b0',1,'dbdead(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dberrhandle_1114',['dberrhandle',['../a00548.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c'],['../a00548.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c']]],
  ['dbexit_1115',['dbexit',['../a00548.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit():&#160;dblib.c'],['../a00548.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit(void):&#160;dblib.c']]],
  ['dbfcmd_1116',['dbfcmd',['../a00548.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c'],['../a00548.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c']]],
  ['dbfirstrow_1117',['dbfirstrow',['../a00554.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbfreebuf_1118',['dbfreebuf',['../a00548.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbgetchar_1119',['dbgetchar',['../a00548.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbproc, int pos):&#160;dblib.c'],['../a00548.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbprocess, int n):&#160;dblib.c']]],
  ['dbgetmaxprocs_1120',['dbgetmaxprocs',['../a00548.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c'],['../a00548.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c']]],
  ['dbgetnull_1121',['dbgetnull',['../a00080.html#aea6a865806d454280126de940478c214',1,'dblib.c']]],
  ['dbgetpacket_1122',['dbgetpacket',['../a00548.html#gabaf9aa756f7cb8bbec80d1c7201c6238',1,'dbgetpacket(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gabaf9aa756f7cb8bbec80d1c7201c6238',1,'dbgetpacket(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbgetrow_1123',['dbgetrow',['../a00548.html#ga60fe544491c760f8bc6c37bc7f777d70',1,'dbgetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c'],['../a00548.html#ga60fe544491c760f8bc6c37bc7f777d70',1,'dbgetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c']]],
  ['dbgettime_1124',['dbgettime',['../a00548.html#ga6ccffbb3f0cfb10883ad349f1e47c50e',1,'dbgettime(void):&#160;dblib.c'],['../a00548.html#ga6ccffbb3f0cfb10883ad349f1e47c50e',1,'dbgettime(void):&#160;dblib.c']]],
  ['dbgetuserdata_1125',['dbgetuserdata',['../a00548.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbhasretstat_1126',['dbhasretstat',['../a00549.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c'],['../a00549.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbinit_1127',['dbinit',['../a00548.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c'],['../a00548.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c']]],
  ['dbiordesc_1128',['dbiordesc',['../a00554.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbiowdesc_1129',['dbiowdesc',['../a00554.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbiscount_1130',['dbiscount',['../a00548.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbisopt_1131',['dbisopt',['../a00548.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00548.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
  ['dblastrow_1132',['dblastrow',['../a00554.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dblogin_1133',['dblogin',['../a00548.html#ga0984798bb806f7451a53bffa7e2c430f',1,'dblogin(void):&#160;dblib.c'],['../a00548.html#ga0984798bb806f7451a53bffa7e2c430f',1,'dblogin(void):&#160;dblib.c']]],
  ['dbloginfree_1134',['dbloginfree',['../a00548.html#gac1bdb1766b791153f37dceae8ff64ad6',1,'dbloginfree(LOGINREC *login):&#160;dblib.c'],['../a00548.html#gac1bdb1766b791153f37dceae8ff64ad6',1,'dbloginfree(LOGINREC *login):&#160;dblib.c']]],
  ['dbmny4add_1135',['dbmny4add',['../a00552.html#ga0a384938a6586b7411fc42420ffad6ed',1,'dbmny4add(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *sum):&#160;dblib.c'],['../a00552.html#ga0a384938a6586b7411fc42420ffad6ed',1,'dbmny4add(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *sum):&#160;dblib.c']]],
  ['dbmny4cmp_1136',['dbmny4cmp',['../a00552.html#ga109d4868baccb08fad3b26b6f031dc78',1,'dbmny4cmp(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c'],['../a00552.html#ga109d4868baccb08fad3b26b6f031dc78',1,'dbmny4cmp(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c']]],
  ['dbmny4copy_1137',['dbmny4copy',['../a00552.html#gaa6d4c700b628f6a18a9d1ed9f8e2ba62',1,'dbmny4copy(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c'],['../a00552.html#gaa6d4c700b628f6a18a9d1ed9f8e2ba62',1,'dbmny4copy(DBPROCESS *dbprocess, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c']]],
  ['dbmny4minus_1138',['dbmny4minus',['../a00552.html#ga76177eb61a67dd52424236aba1b16bc9',1,'dbmny4minus(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c'],['../a00552.html#ga76177eb61a67dd52424236aba1b16bc9',1,'dbmny4minus(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c']]],
  ['dbmny4sub_1139',['dbmny4sub',['../a00552.html#ga856143f4f9c7a5c15fb15633af81487d',1,'dbmny4sub(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *diff):&#160;dblib.c'],['../a00552.html#ga856143f4f9c7a5c15fb15633af81487d',1,'dbmny4sub(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *diff):&#160;dblib.c']]],
  ['dbmny4zero_1140',['dbmny4zero',['../a00552.html#ga070e94f72f12c138a16a7bcdf732fa8b',1,'dbmny4zero(DBPROCESS *dbproc, DBMONEY4 *dest):&#160;dblib.c'],['../a00552.html#ga070e94f72f12c138a16a7bcdf732fa8b',1,'dbmny4zero(DBPROCESS *dbproc, DBMONEY4 *dest):&#160;dblib.c']]],
  ['dbmnycmp_1141',['dbmnycmp',['../a00552.html#gadddacad5c3028aa8d3726246c3825651',1,'dbmnycmp(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2):&#160;dblib.c'],['../a00552.html#gadddacad5c3028aa8d3726246c3825651',1,'dbmnycmp(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2):&#160;dblib.c']]],
  ['dbmnycopy_1142',['dbmnycopy',['../a00552.html#ga8f1e9aa0280c1cb46c10e5c90b8faced',1,'dbmnycopy(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c'],['../a00552.html#ga8f1e9aa0280c1cb46c10e5c90b8faced',1,'dbmnycopy(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnydec_1143',['dbmnydec',['../a00552.html#gabedce74748a31ea8a6e4068a5d44d8e4',1,'dbmnydec(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00552.html#gabedce74748a31ea8a6e4068a5d44d8e4',1,'dbmnydec(DBPROCESS *dbproc, DBMONEY *mnyptr):&#160;dblib.c']]],
  ['dbmnyinc_1144',['dbmnyinc',['../a00552.html#gabf5216aaaa59ea7e7f07899f82a27faf',1,'dbmnyinc(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00552.html#gabf5216aaaa59ea7e7f07899f82a27faf',1,'dbmnyinc(DBPROCESS *dbproc, DBMONEY *mnyptr):&#160;dblib.c']]],
  ['dbmnymaxneg_1145',['dbmnymaxneg',['../a00552.html#gabc3cb44d33bf1b9b18fd59f23e4da722',1,'dbmnymaxneg(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00552.html#gabc3cb44d33bf1b9b18fd59f23e4da722',1,'dbmnymaxneg(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnymaxpos_1146',['dbmnymaxpos',['../a00552.html#ga70ca2474f6c93acd6e3b842330b712c7',1,'dbmnymaxpos(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00552.html#ga70ca2474f6c93acd6e3b842330b712c7',1,'dbmnymaxpos(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnyminus_1147',['dbmnyminus',['../a00552.html#ga826bca98da4fd1c3188da45c383c3a68',1,'dbmnyminus(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c'],['../a00552.html#ga826bca98da4fd1c3188da45c383c3a68',1,'dbmnyminus(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnyzero_1148',['dbmnyzero',['../a00552.html#ga8eab0959d5a3cd534487b350258c939e',1,'dbmnyzero(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c'],['../a00552.html#ga8eab0959d5a3cd534487b350258c939e',1,'dbmnyzero(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmonthname_1149',['dbmonthname',['../a00553.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c'],['../a00553.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c']]],
  ['dbmorecmds_1150',['dbmorecmds',['../a00548.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbmoretext_1151',['dbmoretext',['../a00548.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c'],['../a00548.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c']]],
  ['dbmsghandle_1152',['dbmsghandle',['../a00548.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c'],['../a00548.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c']]],
  ['dbname_1153',['dbname',['../a00548.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbnullbind_1154',['dbnullbind',['../a00548.html#ga85dcc40c3615f94be96b09b2ec043533',1,'dbnullbind(DBPROCESS *dbproc, int column, DBINT *indicator):&#160;dblib.c'],['../a00548.html#ga85dcc40c3615f94be96b09b2ec043533',1,'dbnullbind(DBPROCESS *dbproc, int column, DBINT *indicator):&#160;dblib.c']]],
  ['dbnumalts_1155',['dbnumalts',['../a00548.html#ga67934deac3bebbf8238eff8c0559389a',1,'dbnumalts(DBPROCESS *dbproc, int computeid):&#160;dblib.c'],['../a00548.html#ga67934deac3bebbf8238eff8c0559389a',1,'dbnumalts(DBPROCESS *dbproc, int computeid):&#160;dblib.c']]],
  ['dbnumcols_1156',['dbnumcols',['../a00548.html#gadaa9482a082aa3fe52231e17749c2993',1,'dbnumcols(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gadaa9482a082aa3fe52231e17749c2993',1,'dbnumcols(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbnumcompute_1157',['dbnumcompute',['../a00548.html#gac554d2cb2da0c9f9fd3d4867998edcc4',1,'dbnumcompute(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gac554d2cb2da0c9f9fd3d4867998edcc4',1,'dbnumcompute(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbnumrets_1158',['dbnumrets',['../a00549.html#gaff09873008411a0573f6d1a9e6c7cf4b',1,'dbnumrets(DBPROCESS *dbproc):&#160;dblib.c'],['../a00549.html#gaff09873008411a0573f6d1a9e6c7cf4b',1,'dbnumrets(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbopen_1159',['dbopen',['../a00506.html#ae408d8e1c2ab0767d8bfd26d00d1ff6a',1,'dbopen.c']]],
  ['dbperror_1160',['dbperror',['../a00554.html#ga302a4ce6559b81808e3be51615cd1b67',1,'dbperror(DBPROCESS *dbproc, DBINT msgno, long errnum,...):&#160;dblib.c'],['../a00554.html#ga302a4ce6559b81808e3be51615cd1b67',1,'dbperror(DBPROCESS *dbproc, DBINT msgno, long errnum,...):&#160;dblib.c']]],
  ['dbpivot_1161',['dbpivot',['../a00506.html#af8ada101cd189eff87b3533cbeaaa23b',1,'dbpivot.c']]],
  ['dbprcollen_1162',['dbprcollen',['../a00548.html#gac0cb0584f6500d61a2ac95a891da73eb',1,'dbprcollen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gac0cb0584f6500d61a2ac95a891da73eb',1,'dbprcollen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbprhead_1163',['dbprhead',['../a00548.html#ga9dfc2ee533e5e48a7aa8ca22f8d9ed79',1,'dbprhead(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga9dfc2ee533e5e48a7aa8ca22f8d9ed79',1,'dbprhead(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbprrow_1164',['dbprrow',['../a00548.html#gaa30be3414a97aac6139af2e928db91ca',1,'dbprrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gaa30be3414a97aac6139af2e928db91ca',1,'dbprrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbprtype_1165',['dbprtype',['../a00548.html#gac25ae21ca19777ffab1c013bd6049ebf',1,'dbprtype(int token):&#160;dblib.c'],['../a00548.html#gac25ae21ca19777ffab1c013bd6049ebf',1,'dbprtype(int token):&#160;dblib.c']]],
  ['dbreadtext_1166',['dbreadtext',['../a00548.html#gadd5685565c8c6c86079e17b8a73b324c',1,'dbreadtext(DBPROCESS *dbproc, void *buf, DBINT bufsize):&#160;dblib.c'],['../a00548.html#gadd5685565c8c6c86079e17b8a73b324c',1,'dbreadtext(DBPROCESS *dbproc, void *buf, DBINT bufsize):&#160;dblib.c']]],
  ['dbrecftos_1167',['dbrecftos',['../a00548.html#gabb14ad9f268b92a8d63fa506098b24dd',1,'dbrecftos(const char filename[]):&#160;dblib.c'],['../a00548.html#gabb14ad9f268b92a8d63fa506098b24dd',1,'dbrecftos(const char filename[]):&#160;dblib.c']]],
  ['dbresults_1168',['dbresults',['../a00548.html#ga4e26d949be2c3bf71b1a33c75b11d931',1,'dbresults(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga4e26d949be2c3bf71b1a33c75b11d931',1,'dbresults(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbretdata_1169',['dbretdata',['../a00549.html#ga42e187003b74fec6e9ca92d410bfb9c0',1,'dbretdata(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00549.html#ga42e187003b74fec6e9ca92d410bfb9c0',1,'dbretdata(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretlen_1170',['dbretlen',['../a00549.html#gab705bf94be535e9d8fc4edc0f48c98b0',1,'dbretlen(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00549.html#gab705bf94be535e9d8fc4edc0f48c98b0',1,'dbretlen(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretname_1171',['dbretname',['../a00549.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00549.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretstatus_1172',['dbretstatus',['../a00549.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c'],['../a00549.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbrettype_1173',['dbrettype',['../a00549.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00549.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbrows_1174',['dbrows',['../a00554.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbrowtype_1175',['dbrowtype',['../a00554.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbrpcinit_1176',['dbrpcinit',['../a00549.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c'],['../a00549.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c']]],
  ['dbrpcparam_1177',['dbrpcparam',['../a00549.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int db_type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c'],['../a00549.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c']]],
  ['dbrpcsend_1178',['dbrpcsend',['../a00549.html#gafa4dfd181be21e49c397f7daaa9cf96c',1,'dbrpcsend(DBPROCESS *dbproc):&#160;rpc.c'],['../a00549.html#gafa4dfd181be21e49c397f7daaa9cf96c',1,'dbrpcsend(DBPROCESS *dbproc):&#160;rpc.c']]],
  ['dbsafestr_1179',['dbsafestr',['../a00548.html#gad0ccc03b94ba2515fd1f5d35559fcb41',1,'dbsafestr(DBPROCESS *dbproc, const char *src, DBINT srclen, char *dest, DBINT destlen, int quotetype):&#160;dblib.c'],['../a00548.html#gad0ccc03b94ba2515fd1f5d35559fcb41',1,'dbsafestr(DBPROCESS *dbproc, const char *src, DBINT srclen, char *dest, DBINT destlen, int quotetype):&#160;dblib.c']]],
  ['dbservcharset_1180',['dbservcharset',['../a00548.html#ga39302e8efbb476ba01cff109ffb3661e',1,'dbservcharset(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga39302e8efbb476ba01cff109ffb3661e',1,'dbservcharset(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbsetavail_1181',['dbsetavail',['../a00554.html#ga5ce245ff327a3d333280fe7b43d69ded',1,'dbsetavail(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga5ce245ff327a3d333280fe7b43d69ded',1,'dbsetavail(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbsetifile_1182',['dbsetifile',['../a00548.html#ga663350909fec3a1d152316c45a65e708',1,'dbsetifile(char *filename):&#160;dblib.c'],['../a00548.html#ga663350909fec3a1d152316c45a65e708',1,'dbsetifile(char *filename):&#160;dblib.c']]],
  ['dbsetinterrupt_1183',['dbsetinterrupt',['../a00548.html#ga335fcbe476ad0f897e4e2ce377f0a8cc',1,'dbsetinterrupt(DBPROCESS *dbproc, DB_DBCHKINTR_FUNC chkintr, DB_DBHNDLINTR_FUNC hndlintr):&#160;dblib.c'],['../a00548.html#ga335fcbe476ad0f897e4e2ce377f0a8cc',1,'dbsetinterrupt(DBPROCESS *dbproc, DB_DBCHKINTR_FUNC chkintr, DB_DBHNDLINTR_FUNC hndlintr):&#160;dblib.c']]],
  ['dbsetlbool_1184',['dbsetlbool',['../a00554.html#ga03e850369aca6fba074da5e9da4effd7',1,'dbsetlbool(LOGINREC *login, int value, int which):&#160;dblib.c'],['../a00554.html#ga03e850369aca6fba074da5e9da4effd7',1,'dbsetlbool(LOGINREC *login, int value, int which):&#160;dblib.c']]],
  ['dbsetllong_1185',['dbsetllong',['../a00554.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c'],['../a00554.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c']]],
  ['dbsetlname_1186',['dbsetlname',['../a00554.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c'],['../a00554.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c']]],
  ['dbsetlogintime_1187',['dbsetlogintime',['../a00548.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c'],['../a00548.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c']]],
  ['dbsetlversion_1188',['dbsetlversion',['../a00548.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c'],['../a00548.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c']]],
  ['dbsetmaxprocs_1189',['dbsetmaxprocs',['../a00548.html#gaf2ca0e63f800b3839684c894ff651dd4',1,'dbsetmaxprocs(int maxprocs):&#160;dblib.c'],['../a00548.html#gaf2ca0e63f800b3839684c894ff651dd4',1,'dbsetmaxprocs(int maxprocs):&#160;dblib.c']]],
  ['dbsetnull_1190',['dbsetnull',['../a00548.html#ga399512ec78c15ce3db79ea88ef3b1293',1,'dbsetnull(DBPROCESS *dbproc, int bindtype, int bindlen, BYTE *bindval):&#160;dblib.c'],['../a00548.html#ga399512ec78c15ce3db79ea88ef3b1293',1,'dbsetnull(DBPROCESS *dbprocess, int bindtype, int bindlen, BYTE *bindval):&#160;dblib.c']]],
  ['dbsetopt_1191',['dbsetopt',['../a00548.html#ga9d660d278f3f58871b4086c0e175f4c6',1,'dbsetopt(DBPROCESS *dbproc, int option, const char *char_param, int int_param):&#160;dblib.c'],['../a00548.html#ga9d660d278f3f58871b4086c0e175f4c6',1,'dbsetopt(DBPROCESS *dbproc, int option, const char *char_param, int int_param):&#160;dblib.c']]],
  ['dbsetrow_1192',['dbsetrow',['../a00548.html#gaeb3d621e4f6846bb228b0a596d8758c0',1,'dbsetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c'],['../a00548.html#gaeb3d621e4f6846bb228b0a596d8758c0',1,'dbsetrow(DBPROCESS *dbprocess, DBINT row):&#160;dblib.c']]],
  ['dbsettime_1193',['dbsettime',['../a00548.html#gada4b41f34542a87f0cd87e78e56d18bb',1,'dbsettime(int seconds):&#160;dblib.c'],['../a00548.html#gada4b41f34542a87f0cd87e78e56d18bb',1,'dbsettime(int seconds):&#160;dblib.c']]],
  ['dbsetuserdata_1194',['dbsetuserdata',['../a00548.html#gabea9c70d02bf3e46bbb1d759915cb91e',1,'dbsetuserdata(DBPROCESS *dbproc, BYTE *ptr):&#160;dblib.c'],['../a00548.html#gabea9c70d02bf3e46bbb1d759915cb91e',1,'dbsetuserdata(DBPROCESS *dbproc, BYTE *ptr):&#160;dblib.c']]],
  ['dbsetversion_1195',['dbsetversion',['../a00548.html#gab9aa181fb3081ffb314340cbd71e434d',1,'dbsetversion(DBINT version):&#160;dblib.c'],['../a00548.html#gab9aa181fb3081ffb314340cbd71e434d',1,'dbsetversion(DBINT version):&#160;dblib.c']]],
  ['dbspid_1196',['dbspid',['../a00548.html#ga223a6d333f95e726b0b42ec19a076731',1,'dbspid(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga223a6d333f95e726b0b42ec19a076731',1,'dbspid(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbspr1row_1197',['dbspr1row',['../a00548.html#gaf641c8e3d34607ca8b7ac2afed3e6d67',1,'dbspr1row(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c'],['../a00548.html#gaf641c8e3d34607ca8b7ac2afed3e6d67',1,'dbspr1row(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c']]],
  ['dbspr1rowlen_1198',['dbspr1rowlen',['../a00548.html#ga308918c13a5b1644269c1654fbea96ac',1,'dbspr1rowlen(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga308918c13a5b1644269c1654fbea96ac',1,'dbspr1rowlen(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsprhead_1199',['dbsprhead',['../a00548.html#gaaa4839a9c88e5b90f33bd2407fcbc43e',1,'dbsprhead(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c'],['../a00548.html#gaaa4839a9c88e5b90f33bd2407fcbc43e',1,'dbsprhead(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c']]],
  ['dbsprline_1200',['dbsprline',['../a00548.html#gacfaf9feb29c87cfb660886162f643152',1,'dbsprline(DBPROCESS *dbproc, char *buffer, DBINT buf_len, DBCHAR line_char):&#160;dblib.c'],['../a00548.html#gacfaf9feb29c87cfb660886162f643152',1,'dbsprline(DBPROCESS *dbproc, char *buffer, DBINT buf_len, DBCHAR line_char):&#160;dblib.c']]],
  ['dbsqlexec_1201',['dbsqlexec',['../a00548.html#gaae889abeb145ec41f7361aa8f597fe46',1,'dbsqlexec(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gaae889abeb145ec41f7361aa8f597fe46',1,'dbsqlexec(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsqlok_1202',['dbsqlok',['../a00548.html#gae1f50a6a2c31fda57cb481922b06841e',1,'dbsqlok(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gae1f50a6a2c31fda57cb481922b06841e',1,'dbsqlok(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsqlsend_1203',['dbsqlsend',['../a00548.html#gac980139b9cea03cf93e373d425991481',1,'dbsqlsend(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#gac980139b9cea03cf93e373d425991481',1,'dbsqlsend(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbstrbuild_1204',['dbstrbuild',['../a00548.html#gab5fe0cd5f24d4fd33670111035a4fbed',1,'dbstrbuild(DBPROCESS *dbproc, char *charbuf, int bufsize, char *text, char *formats,...):&#160;dblib.c'],['../a00548.html#gab5fe0cd5f24d4fd33670111035a4fbed',1,'dbstrbuild(DBPROCESS *dbproc, char *charbuf, int bufsize, char *text, char *formats,...):&#160;dblib.c']]],
  ['dbstrcpy_1205',['dbstrcpy',['../a00548.html#gaf130b12e9e58b1bfd4a6685e33f5b3cd',1,'dbstrcpy(DBPROCESS *dbproc, int start, int numbytes, char *dest):&#160;dblib.c'],['../a00548.html#gaf130b12e9e58b1bfd4a6685e33f5b3cd',1,'dbstrcpy(DBPROCESS *dbproc, int start, int numbytes, char *dest):&#160;dblib.c']]],
  ['dbstrlen_1206',['dbstrlen',['../a00548.html#ga13caa07ec45cd6f64e9197d29e3cfe5e',1,'dbstrlen(DBPROCESS *dbproc):&#160;dblib.c'],['../a00548.html#ga13caa07ec45cd6f64e9197d29e3cfe5e',1,'dbstrlen(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbtablecolinfo_1207',['dbtablecolinfo',['../a00548.html#ga9804fc70ae6ed35c92cd75d410dad570',1,'dbtablecolinfo(DBPROCESS *dbproc, DBINT column, DBCOL *pdbcol):&#160;dblib.c'],['../a00548.html#ga9804fc70ae6ed35c92cd75d410dad570',1,'dbtablecolinfo(DBPROCESS *dbproc, DBINT column, DBCOL *pdbcol):&#160;dblib.c']]],
  ['dbtds_1208',['dbtds',['../a00554.html#ga8d765d810a40dfa01b39995a8e7406f0',1,'dbtds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00554.html#ga8d765d810a40dfa01b39995a8e7406f0',1,'dbtds(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbtxptr_1209',['dbtxptr',['../a00548.html#ga57e4098b153a030f0be02bcd98e08ba2',1,'dbtxptr(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga57e4098b153a030f0be02bcd98e08ba2',1,'dbtxptr(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbtxtimestamp_1210',['dbtxtimestamp',['../a00548.html#gac3f11142ec7ff25b1f8972af10fe9454',1,'dbtxtimestamp(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#gac3f11142ec7ff25b1f8972af10fe9454',1,'dbtxtimestamp(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbuse_1211',['dbuse',['../a00548.html#ga66ea891910f0a357cc78107d6ab7d962',1,'dbuse(DBPROCESS *dbproc, const char *name):&#160;dblib.c'],['../a00548.html#ga66ea891910f0a357cc78107d6ab7d962',1,'dbuse(DBPROCESS *dbproc, const char *name):&#160;dblib.c']]],
  ['dbvarylen_1212',['dbvarylen',['../a00548.html#ga57c856964a9a0b4cc43f5192647c51e7',1,'dbvarylen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00548.html#ga57c856964a9a0b4cc43f5192647c51e7',1,'dbvarylen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbversion_1213',['dbversion',['../a00548.html#ga666726c86108342b1c1f27eecf68e13c',1,'dbversion():&#160;dblib.c'],['../a00548.html#ga666726c86108342b1c1f27eecf68e13c',1,'dbversion(void):&#160;dblib.c']]],
  ['dbwillconvert_1214',['dbwillconvert',['../a00548.html#gaaf8349999c16b3c36caf5947747a2915',1,'dbwillconvert(int srctype, int desttype):&#160;dblib.c'],['../a00548.html#gaaf8349999c16b3c36caf5947747a2915',1,'dbwillconvert(int srctype, int desttype):&#160;dblib.c']]],
  ['dbwritetext_1215',['dbwritetext',['../a00548.html#ga548153eb2eae76c48aa9d4b72258dc1c',1,'dbwritetext(DBPROCESS *dbproc, char *objname, DBBINARY *textptr, DBTINYINT textptrlen, DBBINARY *timestamp, DBBOOL log, DBINT size, BYTE *text):&#160;dblib.c'],['../a00548.html#ga548153eb2eae76c48aa9d4b72258dc1c',1,'dbwritetext(DBPROCESS *dbproc, char *objname, DBBINARY *textptr, DBTINYINT textptrlen, DBBINARY *timestamp, DBBOOL log, DBINT size, BYTE *text):&#160;dblib.c']]],
  ['default_5ferr_5fhandler_1216',['default_err_handler',['../a00554.html#gaccbc6d98d9528c48cf0254d809ca73ff',1,'dblib.c']]],
  ['determine_5fadjusted_5fsize_1217',['determine_adjusted_size',['../a00565.html#gaacb26868882440aa08de9fb952628eaf',1,'token.c']]]
];
